<template>
  <FormSection
    description="app.profile.details.description"
    title="app.profile.details.title"
  >
    <FormGroup @submit="submit">
      <AlertError v-if="form.errors && form.errors?.unknown">
        {{ form.errors.unknown }}
      </AlertError>
      <FormInput
        id="profile_name"
        :errors="form.errors.name"
      >
        <FormLabel>{{ $t("app.profile.form.name") }}</FormLabel>
        <FormText
          v-model="form.values.name"
          autocomplete="given-name"
          name="name"
          required
          type="text"
        />
      </FormInput>
      <FormInput
        id="profile_email"
        :errors="form.errors.email"
      >
        <FormLabel>{{ $t("app.profile.form.email") }}</FormLabel>
        <FormText
          v-model="form.values.email"
          autocomplete="email"
          name="email"
          required
          type="email"
        />
      </FormInput>
      <div>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-black"
        >
          {{ $t("app.profile.details.submit") }}
        </FormSubmit>
      </div>
    </FormGroup>
  </FormSection>
</template>

<script lang="ts" setup>
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import FormSection from "@/js/contexts/form/ui/components/FormSection.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import useAuth from "@/js/contexts/auth/composables/useAuth";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const props = defineProps<{
  name: string;
  email: string;
}>();
const { t } = useI18n();
const { fetchUser } = useAuth();
const { successNotification } = useNotification();

const form = useForm({
  name: props.name,
  email: props.email,
});

const submit = () => {
  form.post("/profile", {
    onSuccess: () => {
      fetchUser();
      successNotification(t("app.profile.details.success"));
    },
  });
};
</script>
